@@ -487,6 +487,8 @@ class SOStringLikeCol(SOCol):
         return type
 
     def _mssqlType(self):
+        if self.customSQLType is not None:
+            return self.customSQLType
         if not self.length:
             type = 'varchar(4000)'
         elif self.varchar:
@@ -601,7 +603,7 @@ class SOIntCol(SOCol):
     def __init__(self, **kw):
         self.length = popKey(kw, 'length')
         self.unsigned = bool(popKey(kw, 'unsigned'))
-        self.zerofill = bool(popKey(kw, 'unsigned'))
+        self.zerofill = bool(popKey(kw, 'zerofill'))
         SOCol.__init__(self, **kw)
 
     def autoConstraints(self):
@@ -689,7 +691,7 @@ class SOBoolCol(SOCol):
         return 'BOOL'
 
     def _mysqlType(self):
-        return "TINYINT"
+        return "BOOL"
 
     def _sybaseType(self):
         return "BIT"
@@ -786,7 +788,7 @@ class SOForeignKey(SOKeyCol):
 
     def sqliteCreateSQL(self):
         sql = SOKeyCol.sqliteCreateSQL(self)
-        other = findClass(self.foreignKey)
+        other = findClass(self.foreignKey, self.soClass.sqlmeta.registry)
         tName = other.sqlmeta.table
         idName = other.sqlmeta.idName
         if self.cascade is not None:
@@ -868,7 +870,7 @@ class SOForeignKey(SOKeyCol):
 
     def sybaseCreateSQL(self):
         sql = SOKeyCol.sybaseCreateSQL(self)
-        other = findClass(self.foreignKey)
+        other = findClass(self.foreignKey, self.soClass.sqlmeta.registry)
         tName = other.sqlmeta.table
         idName = other.sqlmeta.idName
         reference = ('REFERENCES %(tName)s(%(idName)s) ' %
@@ -883,7 +885,7 @@ class SOForeignKey(SOKeyCol):
 
     def mssqlCreateSQL(self):
         sql = SOKeyCol.mssqlCreateSQL(self)
-        other = findClass(self.foreignKey)
+        other = findClass(self.foreignKey, self.soClass.sqlmeta.registry)
         tName = other.sqlmeta.table
         idName = other.sqlmeta.idName
         reference = ('REFERENCES %(tName)s(%(idName)s) ' %
@@ -897,7 +899,7 @@ class SOForeignKey(SOKeyCol):
         return None
 
     def maxdbCreateSQL(self):
-        other = findClass(self.foreignKey)
+        other = findClass(self.foreignKey, self.soClass.sqlmeta.registry)
         fidName = self.dbName
         #I assume that foreign key name is identical to the id of the reference table
         sql = ' '.join([fidName, self._maxdbType()])
@@ -1396,6 +1398,11 @@ class BinaryValidator(validators.Validator):
         return binary
 
 class SOBLOBCol(SOStringCol):
+    def __init__(self, **kw):
+        # Change the default from 'auto' to False - this is a (mostly) binary column
+        if 'varchar' not in kw: kw['varchar'] = False
+        super(SOBLOBCol, self).__init__(**kw)
+
     def createValidators(self):
         return [BinaryValidator(name=self.name)] + \
             super(SOBLOBCol, self).createValidators()
