@@ -2,7 +2,7 @@ from sqlobject import sqlbuilder
 from sqlobject import classregistry
 from sqlobject.col import StringCol, ForeignKey
 from sqlobject.main import sqlmeta, SQLObject, SelectResults, True, False, \
-   makeProperties, getterName, setterName
+   makeProperties, unmakeProperties, getterName, setterName
 import iteration
 
 
@@ -33,11 +33,11 @@ class InheritableSelectResults(SelectResults):
         if clause is None or isinstance(clause, str) and clause == 'all':
             clause = sqlbuilder.SQLTrueClause
         tablesDict = tablesUsedDict(clause)
-        tablesDict[sourceClass.sqlmeta.table] = 1
+        tablesDict[str(sourceClass.sqlmeta.table)] = 1
         orderBy = ops.get('orderBy')
         if inheritedTables:
             for tableName in inheritedTables:
-                tablesDict[tableName] = 1
+                tablesDict[str(tableName)] = 1
         if orderBy and not isinstance(orderBy, basestring):
             tablesDict.update(tablesUsedDict(orderBy))
         #DSM: if this class has a parent, we need to link it
@@ -51,7 +51,7 @@ class InheritableSelectResults(SelectResults):
             allClasses = classregistry.registry(
                 sourceClass.sqlmeta.registry).allClasses()
             for registryClass in allClasses:
-                if registryClass.sqlmeta.table in tablesDict:
+                if str(registryClass.sqlmeta.table) in tablesDict:
                     #DSM: By default, no parents are needed for the clauses
                     tableRegistry[registryClass] = registryClass
             tableRegistryCopy = tableRegistry.copy()
@@ -78,7 +78,7 @@ class InheritableSelectResults(SelectResults):
                     parentClass = currentClass.sqlmeta.parentClass
                     parentClause.append(currentClass.q.id == parentClass.q.id)
                     currentClass = parentClass
-                    tablesDict[currentClass.sqlmeta.table] = 1
+                    tablesDict[str(currentClass.sqlmeta.table)] = 1
             clause = reduce(sqlbuilder.AND, parentClause, clause)
 
         super(InheritableSelectResults, self).__init__(sourceClass,
@@ -131,19 +131,27 @@ class InheritableSQLMeta(sqlmeta):
 
     addColumn = classmethod(addColumn)
 
-    def delColumn(sqlmeta, column, changeSchema=False, connection=None):
-        soClass = sqlmeta.soClass
-        super(InheritableSQLMeta, sqlmeta).delColumn(column, changeSchema, connection)
+    def delColumn(sqlmeta, column, changeSchema=False, connection=None, childUpdate=False):
+        if childUpdate:
+            soClass = sqlmeta.soClass
+            unmakeProperties(soClass)
+            makeProperties(soClass)
 
-        if isinstance(column, str):
-            name = column
-        else:
-            name = column.name
+            if isinstance(column, str):
+                name = column
+            else:
+                name = column.name
+            delattr(soClass, name)
+            delattr(soClass.q, name)
+            return
+
+        super(InheritableSQLMeta, sqlmeta).delColumn(column, changeSchema, connection)
 
         #DSM: Update each child class if needed
         #DSM: and delete properties for this column
         for c in sqlmeta.childClasses.values():
-            delattr(c.q, name)
+            c.sqlmeta.delColumn(column, changeSchema=changeSchema,
+                connection=connection, childUpdate=True)
 
     delColumn = classmethod(delColumn)
 
@@ -178,18 +186,37 @@ class InheritableSQLMeta(sqlmeta):
 
     addJoin = classmethod(addJoin)
 
-    def delJoin(sqlmeta, joinDef):
-        soClass = sqlmeta.soClass
+    def delJoin(sqlmeta, joinDef, childUpdate=False):
+        if childUpdate:
+            soClass = sqlmeta.soClass
+            unmakeProperties(soClass)
+            makeProperties(soClass)
+            return
+
         super(InheritableSQLMeta, sqlmeta).delJoin(joinDef)
 
         #DSM: Update each child class if needed
         #DSM: and delete properties for this join
         for c in sqlmeta.childClasses.values():
-            # FIXME: what is ``meth``?
-            delattr(c, meth)
+            c.sqlmeta.delJoin(joinDef, childUpdate=True)
 
     delJoin = classmethod(delJoin)
 
+    def getAllColumns(sqlmeta):
+        columns = sqlmeta.columns.copy()
+        sm = sqlmeta
+        while sm.parentClass:
+            columns.update(sm.parentClass.sqlmeta.columns)
+            sm = sm.parentClass.sqlmeta
+        return columns
+
+    def asDict(sqlmeta):
+        result = {}
+        for key in sqlmeta.getAllColumns():
+            result[key] = getattr(sqlmeta.instance, key)
+        result['id'] = sqlmeta.instance.id
+        return result
+
 
 class InheritableSQLObject(SQLObject):
 
