@@ -343,6 +343,19 @@ class UnicodeField(SQLObjectField):
         if isinstance(other, unicode):
             other = other.encode(self.column.dbEncoding)
         return SQLOp('<>', self, other)
+    def startswith(self, s):
+        if isinstance(s, unicode):
+            s = s.encode(self.column.dbEncoding)
+        return STARTSWITH(self, s)
+    def endswith(self, s):
+        if isinstance(s, unicode):
+            s = s.encode(self.column.dbEncoding)
+        return ENDSWITH(self, s)
+    def contains(self, s):
+        if isinstance(s, unicode):
+            s = s.encode(self.column.dbEncoding)
+        return CONTAINSSTRING(self, s)
+
 
 registerConverter(UnicodeField, SQLExprConverter)
 
@@ -723,9 +736,11 @@ class _LikeQuoted:
                 return "CONCAT(%s)" % ", ".join(values)
             else:
                 return " || ".join(values)
-        else: # assuming s is a string
-            s = _quote_percent(s, db)
+        elif isinstance(s, (str, unicode)):
+            s = _quote_percent(sqlrepr(s, db)[1:-1], db)
             return "'%s%s%s'" % (self.prefix, s, self.postfix)
+        else:
+           raise TypeError, "expected str, unicode or SQLExpression, got %s" % type(s)
 
 def _quote_percent(s, db):
     if db in ('postgres', 'mysql'):
